@@ -138,11 +138,10 @@ class MainWindow(QtWidgets.QMainWindow):
         self.label_dock = QtWidgets.QDockWidget(self.tr(u'Label List'), self)
         self.label_dock.setObjectName(u'Label List')
         self.label_dock.setWidget(self.uniqLabelList)
-
+        
+        self.fileName = QtWidgets.QLineEdit()
+        self.fileName.setPlaceholderText(self.tr('Waiting for file to load...'))
         self.fileSearch = QtWidgets.QLineEdit()
-        # try:
-        #     self.fileSearch.setPlaceholderText(self.tr(self.filename))
-        # except Exception:
         self.fileSearch.setPlaceholderText(self.tr('Search Filename'))
         self.fileSearch.textChanged.connect(self.fileSearchChanged)
         self.fileListWidget = QtWidgets.QListWidget()
@@ -152,6 +151,7 @@ class MainWindow(QtWidgets.QMainWindow):
         fileListLayout = QtWidgets.QVBoxLayout()
         fileListLayout.setContentsMargins(0, 0, 0, 0)
         fileListLayout.setSpacing(0)
+        fileListLayout.addWidget(self.fileName)
         fileListLayout.addWidget(self.fileSearch)
         fileListLayout.addWidget(self.fileListWidget)
         self.file_dock = QtWidgets.QDockWidget(self.tr(u'File List'), self)
@@ -1010,9 +1010,6 @@ class MainWindow(QtWidgets.QMainWindow):
         if item and not isinstance(item, LabelListWidgetItem):
             raise TypeError("item must be LabelListWidgetItem type")
         
-        if item and not isinstance(item, QtWidgets.QListWidgetItem):
-            raise TypeError('unsupported type of item: {}'.format(type(item)))
-
         if not self.canvas.editing():
             return
         if not item:
@@ -1043,8 +1040,10 @@ class MainWindow(QtWidgets.QMainWindow):
         else:
             item.setText('{} ({})'.format(shape.label, shape.group_id))
         self.setDirty()
-        if not self.uniqLabelList.findItems(shape.label, Qt.MatchExactly):
-            self.uniqLabelList.addItem(shape.label)
+        if not self.uniqLabelList.findItemsByLabel(shape.label):
+            item = QtWidgets.QListWidgetItem()
+            item.setData(Qt.UserRole, shape.label)
+            self.uniqLabelList.addItem(item)
 
     def fileSearchChanged(self):
         self.importDirImages(
@@ -1421,6 +1420,7 @@ class MainWindow(QtWidgets.QMainWindow):
         if filename is None:
             filename = self.settings.value('filename', '')
         filename = str(filename)
+        self.fileName.setText(filename)
         if not QtCore.QFile.exists(filename):
             self.errorMessage(
                 self.tr('Error opening file'),
@@ -1666,6 +1666,7 @@ class MainWindow(QtWidgets.QMainWindow):
         self._config['keep_prev'] = keep_prev
 
     def openFile(self, _value=False):
+        self.canvas.dialog = True
         if not self.mayContinue():
             return
         self.loadTime = str(datetime.now())
@@ -1682,8 +1683,10 @@ class MainWindow(QtWidgets.QMainWindow):
         filename = str(filename)
         if filename:
             self.loadFile(filename)
+        self.canvas.dialog = False
 
     def changeOutputDirDialog(self, _value=False):
+        self.canvas.dialog = True
         default_output_dir = self.output_dir
         if default_output_dir is None and self.filename:
             default_output_dir = osp.dirname(self.filename)
@@ -1711,6 +1714,7 @@ class MainWindow(QtWidgets.QMainWindow):
 
         current_filename = self.filename
         self.importDirImages(self.lastOpenDir, load=False)
+        self.canvas.dialog = False
 
         if current_filename in self.imageList:
             # retain currently selected file
@@ -1884,31 +1888,31 @@ class MainWindow(QtWidgets.QMainWindow):
         self.setDirty()
 
     def openDirDialog(self, _value=False, dirpath=None):
+        self.canvas.dialog = True
         if not self.mayContinue():
             return
 
-        try:
-            defaultOpenDirPath = dirpath if dirpath else "."
-            if self.lastOpenDir and osp.exists(self.lastOpenDir):
-                defaultOpenDirPath = self.lastOpenDir
-            else:
-                defaultOpenDirPath = (
-                    osp.dirname(self.filename) if self.filename else "."
-                )
-
-            targetDirPath = str(
-                QtWidgets.QFileDialog.getExistingDirectory(
-                    self,
-                    self.tr("%s - Open Directory") % __appname__,
-                    defaultOpenDirPath,
-                    QtWidgets.QFileDialog.ShowDirsOnly
-                    | QtWidgets.QFileDialog.DontResolveSymlinks,
-                )
+        defaultOpenDirPath = dirpath if dirpath else "."
+        if self.lastOpenDir and osp.exists(self.lastOpenDir):
+            defaultOpenDirPath = self.lastOpenDir
+        else:
+            defaultOpenDirPath = (
+                osp.dirname(self.filename) if self.filename else "."
             )
-            self.importDirImages(targetDirPath)
-        except:
-            pass
 
+        targetDirPath = str(
+            QtWidgets.QFileDialog.getExistingDirectory(
+                self,
+                self.tr("%s - Open Directory") % __appname__,
+                defaultOpenDirPath,
+                QtWidgets.QFileDialog.ShowDirsOnly
+                | QtWidgets.QFileDialog.DontResolveSymlinks,
+            )
+        )
+        self.importDirImages(targetDirPath)
+        self.canvas.dialog = False
+            
+            
     @property
     def imageList(self):
         lst = []
