@@ -86,6 +86,7 @@ class Canvas(QtWidgets.QWidget):
         self.setFocusPolicy(QtCore.Qt.WheelFocus)
         self.cross = False
         self.posc = None
+        self.dialog = False
 
     def fillDrawing(self):
         return self._fill_drawing
@@ -539,7 +540,7 @@ class Canvas(QtWidgets.QWidget):
                 self.cross_temp = 1
                 self.cross = True
             try:
-                if self.cross == True and self.pixmap:
+                if self.cross == True and self.pixmap and self.dialog == False:
                     p.setPen(QtGui.QPen(QtCore.Qt.black, 0.9, QtCore.Qt.DashLine))
                     p.drawLine(self.posc.x(), self.pixmap.height(), self.posc.x(), 0)
                     p.drawLine(0, self.posc.y(), self.pixmap.width(), self.posc.y())
